MapLatLngBounds class

Bounds of the maps.

Annotations

Constructors

MapLatLngBounds(MapLatLng northeast, MapLatLng southwest)
Creates a MapLatLngBounds.
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
northeast → MapLatLng
The northeast MapLatLng bound.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
southwest → MapLatLng
The southwest MapLatLng bound.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override